[![Downloads](https://static.pepy.tech/personalized-badge/mammath?period=total&units=international_system&left_color=grey&right_color=brightgreen&left_text=Mammath%20downloads)](https://pepy.tech/project/mammath) - <a href="https://pypi.org/project/mammath/" target="_blank">Mammath on Pypi</a>
<br>
Mammath is the python library with all the functions you need to do complicated mathematics, anywhere from 2D and 3D graphing calculators to linear algebra, calculus and even physics. We even have a constant and function for practically everything
<br>

<h1><b> Release notes 0.3.1 - Bugfixes and deletions directly after 0.3.0</b></h1>
<ul>
    <li>Removed deprecated functions</li>  
    <li>Methods are all grouped by category. For instance, all calculus functions can be accessed through mammath.calculus, as well as the standard import</li>  
    <li>Added many new graphs, including the Mandelbrot set (quite spectacular with almost infinite zoom capabilities using the <code>mandelbrot_explorer()</code> class), and other useful plots. The graphing functions have been updated with one function for a function for parametric and Cartesian graphing in 2 and 3 dimensions, as well as complex number functions.</li>  
    <li>Changed checkers_and_printers to special numbers and refactored the method names to be more intuitive</li>  
    <li>Added two new tables</li>  
    <li>Added new sequencing methods (arithmetic sums, geometric sums, etc.)</li>  
    <li>Created many new physics methods, including time dilation methods, path integrals, and even a photoelectric effect simulator</li>  
    <li>New linear algebra classes - Vector and Matrix, which each come will useful methods. Methods to compute linear least squares, eigenvalues, and more.</li>  
    <li>Many new complex functions, including complex hyperbolic methods, the Lambert W function, and the gamma function</li>  
    <li>New coordinate geometry section. It already has a multitude of features from the construction of special triangle cevians and special centers (more than you think), to rotations and reflections. We plan to continue expanding this section to a full-on coordinate-based geometry engine with complex geometrical operations</li>  
    <li>Created many new calculus functions, from integral approximations like the trapezoidal rule, to multivariable calculus (partial derivatives, divergence, and curl). There are also new methods for each calculus function that allow you to visualize the actual function (e.g. derivative calculates the derivative at a point but f_derivative produces a function that can be used to compute, graph, and so much more)</li>
</ul>

Enjoy some cool graphs that can be made with the newest release of mammath:

<p float="left">
  <img src="https://github.com/vhprogrammingorg/mammath/assets/91592863/92a74089-c1c7-444d-9019-8d66530b5deb" width="45%" />
  <img src="https://github.com/vhprogrammingorg/mammath/assets/91592863/de187fb5-5007-4fec-a7f1-59f8d453ac1c" width="45%" />
</p>
<p float="left">
  <img src="https://github.com/vhprogrammingorg/mammath/assets/91592863/8f4abcda-5256-4c57-9a72-cd43ab6edd84" width="45%" />
  <img src="https://github.com/vhprogrammingorg/mammath/assets/91592863/465a3840-ae29-4522-a1bd-8e9dc55d27a1" width="45%" />
</p>
<p float="left">
  <img src="https://github.com/vhprogrammingorg/mammath/assets/91592863/bd335740-d3d9-44d3-8569-f19d00a1d54b" width="90%" />
</p>


It is built upon several other modules including sys, tkinter, string, time, math, cmath, fractions, mpmath, keyboard, numpy, tabulate, re, matplotlib, and modules within them. 

| All categories                                    | All categories    |
| :----------------------------------------------- | :-------------- |
| Shunting Yard Algorithm                          | Math Teachers (beta ascii courses)   |
| Operations (logs, factorials, standard form, sums, hcf, lcm, etc.) | Prime Numbers|
| Number / Sequence Checks                         | Fibonacci        |
| Divisibility checks + learn tricks (beta)        | Fractions        |
| Geometry                                         | Sequences        |
| Constants                                         | Base conversions |
| Graphing                                         | Algebra          |
| Linear Algebra                                   | Calculus         |
| Complex (complex ln, etc.) | Physics             |
| Unit conversions    |  Miscellaneous (Equation parser, special numbers)|
| Coordinate Geometry | Deprecated |

We hope Mammath is a useful and reliable asset. Install via <code>pip install mammath</code>

Thank you!
